Road Map
========


Short Term
----------

- Write more example programs
- Tidy up many of the core objects
- Add a builtins object ala Python's builtins
- Implement an importer for importing modules
- Better semantics and validation of traits
- Reduce the amount of Python implementation code
- Basic FFI mechanism into Python and primitives


Long Term
---------

- Write a compiler and bytecode virtual machine
- Add coroutine support and multiprocessing
- Add exception handling
- Rewrite in RPython to take advantage of PyPy's JIT and STM
